#include <stdlib.h>

#include "sylimits.h"
#include "data.h"
#include "error.h"

void
init_if(struct stream *st)
{
    fatal("if module not available");
}
void
gets_if(void)
{
    fatal("if module not available");
}
int
get_if(char *symon_buf, int maxlen, struct stream *st)
{
    fatal("if module not available");

    /* NOT REACHED */
    return 0;
}
